@@ -1,4 +1,4 @@
-/* $Id: fsusage.h,v 1.20 2004/04/07 10:05:51 hadess Exp $ */
+/* $Id: fsusage.h,v 1.23 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
 
@@ -34,8 +34,9 @@ G_BEGIN_DECLS
 #define GLIBTOP_FSUSAGE_FILES		3
 #define GLIBTOP_FSUSAGE_FFREE		4
 #define GLIBTOP_FSUSAGE_BLOCK_SIZE	5
-
-#define GLIBTOP_MAX_FSUSAGE		6
+#define GLIBTOP_FSUSAGE_READ           6
+#define GLIBTOP_FSUSAGE_WRITE          7
+#define GLIBTOP_MAX_FSUSAGE		8
 
 
 typedef struct _glibtop_fsusage		glibtop_fsusage;
@@ -48,7 +49,8 @@ struct _glibtop_fsusage
 		bavail,		/* Free blocks available to non-superuser. */
 		files,		/* Total file nodes. */
 		ffree;		/* Free file nodes. */
-	gint	block_size;	/* Size of a block in bytes. */
+	guint32	block_size;	/* Size of a block in bytes. */
+	guint64 read, write;    /* Total blocks read and written */
 };
 
 #define glibtop_get_fsusage(fsusage,disk)	glibtop_get_fsusage_l(glibtop_global_server, fsusage, disk)
@@ -58,16 +60,6 @@ struct _glibtop_fsusage
 void glibtop_get_fsusage_l (glibtop *server, glibtop_fsusage *buf, const char *mount_dir);
 void glibtop_get_fsusage_s (glibtop *server, glibtop_fsusage *buf, const char *mount_dir);
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_fsusage [];
-extern const unsigned glibtop_types_fsusage [];
-extern const char *glibtop_labels_fsusage [];
-extern const char *glibtop_descriptions_fsusage [];
-
-#endif
 
 G_END_DECLS
 
