@@ -1,4 +1,4 @@
-/* $Id: sysdeps.h,v 1.34 2004/11/13 00:53:20 bdejean Exp $ */
+/* $Id: sysdeps.h,v 1.35 2004/12/06 14:44:10 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -96,16 +96,6 @@ struct _glibtop_sysdeps
 
 void glibtop_get_sysdeps_r (glibtop *server, glibtop_sysdeps *buf);
 
-#ifdef GLIBTOP_NAMES
-
-/* You need to link with -lgtop_names to get this stuff here. */
-
-extern const char *glibtop_names_sysdeps [];
-extern const unsigned glibtop_types_sysdeps [];
-extern const char *glibtop_labels_sysdeps [];
-extern const char *glibtop_descriptions_sysdeps [];
-
-#endif
 
 G_END_DECLS
 
