@@ -49,6 +49,7 @@ _glibtop_missing_feature (glibtop *server, const char *feature,
 void
 glibtop_get_cpu_l (glibtop *server, glibtop_cpu *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -82,6 +83,7 @@ glibtop_get_cpu_l (glibtop *server, glibtop_cpu *buf)
 void
 glibtop_get_mem_l (glibtop *server, glibtop_mem *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -115,6 +117,7 @@ glibtop_get_mem_l (glibtop *server, glibtop_mem *buf)
 void
 glibtop_get_swap_l (glibtop *server, glibtop_swap *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -148,6 +151,7 @@ glibtop_get_swap_l (glibtop *server, glibtop_swap *buf)
 void
 glibtop_get_uptime_l (glibtop *server, glibtop_uptime *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -181,6 +185,7 @@ glibtop_get_uptime_l (glibtop *server, glibtop_uptime *buf)
 void
 glibtop_get_loadavg_l (glibtop *server, glibtop_loadavg *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -214,6 +219,7 @@ glibtop_get_loadavg_l (glibtop *server, glibtop_loadavg *buf)
 void
 glibtop_get_shm_limits_l (glibtop *server, glibtop_shm_limits *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -247,6 +253,7 @@ glibtop_get_shm_limits_l (glibtop *server, glibtop_shm_limits *buf)
 void
 glibtop_get_msg_limits_l (glibtop *server, glibtop_msg_limits *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -280,6 +287,7 @@ glibtop_get_msg_limits_l (glibtop *server, glibtop_msg_limits *buf)
 void
 glibtop_get_sem_limits_l (glibtop *server, glibtop_sem_limits *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 
@@ -314,10 +322,16 @@ unsigned *
 glibtop_get_proclist_l (glibtop *server, glibtop_proclist *buf,
                         gint64 which, gint64 arg)
 {
-	const void *send_ptr = &which;
-	const size_t send_size =
-		sizeof (which) + sizeof (arg);
+	struct {
+		gint64 buf_which;
+		gint64 buf_arg;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
 	unsigned * retval = (unsigned *) 0;
+	param_buf.buf_which = which;
+	param_buf.buf_arg = arg;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROCLIST), 0);
 
@@ -354,9 +368,13 @@ void
 glibtop_get_proc_state_l (glibtop *server, glibtop_proc_state *buf,
                           pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_STATE), 0);
 
@@ -389,9 +407,13 @@ void
 glibtop_get_proc_uid_l (glibtop *server, glibtop_proc_uid *buf,
                         pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_UID), 0);
 
@@ -424,9 +446,13 @@ void
 glibtop_get_proc_mem_l (glibtop *server, glibtop_proc_mem *buf,
                         pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_MEM), 0);
 
@@ -459,9 +485,13 @@ void
 glibtop_get_proc_time_l (glibtop *server, glibtop_proc_time *buf,
                          pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_TIME), 0);
 
@@ -494,9 +524,13 @@ void
 glibtop_get_proc_signal_l (glibtop *server, glibtop_proc_signal *buf,
                            pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_SIGNAL), 0);
 
@@ -529,9 +563,13 @@ void
 glibtop_get_proc_kernel_l (glibtop *server, glibtop_proc_kernel *buf,
                            pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_KERNEL), 0);
 
@@ -564,9 +602,13 @@ void
 glibtop_get_proc_segment_l (glibtop *server, glibtop_proc_segment *buf,
                             pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_SEGMENT), 0);
 
@@ -599,10 +641,16 @@ char *
 glibtop_get_proc_args_l (glibtop *server, glibtop_proc_args *buf,
                          pid_t pid, unsigned max_len)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid) + sizeof (max_len);
+	struct {
+		pid_t buf_pid;
+		unsigned buf_max_len;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
 	char * retval = (char *) 0;
+	param_buf.buf_pid = pid;
+	param_buf.buf_max_len = max_len;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_ARGS), 0);
 
@@ -639,10 +687,14 @@ glibtop_map_entry *
 glibtop_get_proc_map_l (glibtop *server, glibtop_proc_map *buf,
                         pid_t pid)
 {
-	const void *send_ptr = &pid;
-	const size_t send_size =
-		sizeof (pid);
+	struct {
+		pid_t buf_pid;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
 	glibtop_map_entry * retval = (glibtop_map_entry *) 0;
+	param_buf.buf_pid = pid;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PROC_MAP), 0);
 
@@ -679,10 +731,14 @@ glibtop_mountentry *
 glibtop_get_mountlist_l (glibtop *server, glibtop_mountlist *buf,
                          int all_fs)
 {
-	const void *send_ptr = &all_fs;
-	const size_t send_size =
-		sizeof (all_fs);
+	struct {
+		int buf_all_fs;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
 	glibtop_mountentry * retval = (glibtop_mountentry *) 0;
+	param_buf.buf_all_fs = all_fs;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_MOUNTLIST), 0);
 
@@ -714,6 +770,7 @@ void
 glibtop_get_fsusage_l (glibtop *server, glibtop_fsusage *buf,
                        const char *mount_dir)
 {
+
 	const void *send_ptr = mount_dir;
 	const size_t send_size =
 		strlen (mount_dir) + 1;
@@ -744,6 +801,7 @@ void
 glibtop_get_netload_l (glibtop *server, glibtop_netload *buf,
                        const char *interface)
 {
+
 	const void *send_ptr = interface;
 	const size_t send_size =
 		strlen (interface) + 1;
@@ -779,9 +837,13 @@ void
 glibtop_get_ppp_l (glibtop *server, glibtop_ppp *buf,
                    unsigned short device)
 {
-	const void *send_ptr = &device;
-	const size_t send_size =
-		sizeof (device);
+	struct {
+		unsigned short buf_device;
+	} param_buf;
+
+	const void *send_ptr = &param_buf;
+	const size_t send_size = sizeof param_buf;
+	param_buf.buf_device = device;
 
 	glibtop_init_r (&server, (1 << GLIBTOP_SYSDEPS_PPP), 0);
 
@@ -813,6 +875,7 @@ glibtop_get_ppp_l (glibtop *server, glibtop_ppp *buf,
 char **
 glibtop_get_netlist_l (glibtop *server, glibtop_netlist *buf)
 {
+
 	const void *send_ptr = NULL;
 	const size_t send_size = 0;
 	char ** retval = (char **) 0;
